# Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/loftusa"><img src="https://avatars.githubusercontent.com/u/12386450?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alex Loftus</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=loftusa" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/asaadeldin11"><img src="https://avatars.githubusercontent.com/u/54996865?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ali Saad-Eldin</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=asaadeldin11" title="Code">💻</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/anshu-trivedi-501a7b146/"><img src="https://avatars.githubusercontent.com/u/47869948?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Anshu Trivedi</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=AnshuTrivedi" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/falkben"><img src="https://avatars.githubusercontent.com/u/653031?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ben Falk</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=falkben" title="Code">💻</a></td>
    <td align="center"><a href="https://bdpedigo.github.io/"><img src="https://avatars.githubusercontent.com/u/25714207?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Benjamin Pedigo</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=bdpedigo" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/bvarjavand"><img src="https://avatars.githubusercontent.com/u/8294669?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Bijan Varjavand</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=bvarjavand" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/bryantower"><img src="https://avatars.githubusercontent.com/u/583566?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Bryan Tower</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=bryantower" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/carolyncb"><img src="https://avatars.githubusercontent.com/u/60894394?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Carolyn Buractaon</b></sub></a><br /><a href="#projectManagement-carolyncb" title="Project Management">📆</a></td>
    <td align="center"><a href="https://github.com/CaseyWeiner"><img src="https://avatars.githubusercontent.com/u/54880846?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Casey Weiner</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=CaseyWeiner" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/dtborders"><img src="https://avatars.githubusercontent.com/u/32661399?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Daniel Borders</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=dtborders" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/dwaynepryce"><img src="https://avatars.githubusercontent.com/u/899411?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Dwayne Pryce</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=dwaynepryce" title="Code">💻</a></td>
    <td align="center"><a href="http://ericwb.me/"><img src="https://avatars.githubusercontent.com/u/8883547?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eric Bridgeford</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=ebridge2" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/PSSF23"><img src="https://avatars.githubusercontent.com/u/20309845?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Haoyin Xu</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=PSSF23" title="Code">💻</a></td>
    <td align="center"><a href="https://idc9.github.io/"><img src="https://avatars.githubusercontent.com/u/906398?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Iain Carmichael</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=idc9" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://twitter.com/j1chung"><img src="https://avatars.githubusercontent.com/u/5142539?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jaewon Chung</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=j1c" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/jdey4"><img src="https://avatars.githubusercontent.com/u/52499217?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jayanta Dey</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=jdey4" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/shaderein"><img src="https://avatars.githubusercontent.com/u/47577845?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jinhan</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=shaderein" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/jonmclean"><img src="https://avatars.githubusercontent.com/u/4429525?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jon McLean</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=jonmclean" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/Nyecarr"><img src="https://avatars.githubusercontent.com/u/4693255?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Nick</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=Nyecarr" title="Code">💻</a></td>
    <td align="center"><a href="http://www.patrickbourke.com"><img src="https://avatars.githubusercontent.com/u/37699?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Patrick Bourke</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=pbourke" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/pauladkisson"><img src="https://avatars.githubusercontent.com/u/34703136?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Paul Adkisson</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=pauladkisson" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://www.linkedin.com/in/pratyush-raj-737809193/"><img src="https://avatars.githubusercontent.com/u/53184883?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Pratyush Raj</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=rajpratyush" title="Code">💻</a></td>
    <td align="center"><a href="https://rflperry.github.io/"><img src="https://avatars.githubusercontent.com/u/13107341?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ronan Perry</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=rflperry" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/darkyed"><img src="https://avatars.githubusercontent.com/u/43502778?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Saumitra Sharma</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=darkyed" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/SHAAAAN"><img src="https://avatars.githubusercontent.com/u/45969738?v=4?s=100" width="100px;" alt=""/><br /><sub><b>ShanQiu</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=SHAAAAN" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/shiyussy"><img src="https://avatars.githubusercontent.com/u/50231743?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Shiyu Sun</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=shiyussy" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/tathey1"><img src="https://avatars.githubusercontent.com/u/18537350?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Thomas Athey</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=tathey1" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/vikramc1"><img src="https://avatars.githubusercontent.com/u/7087830?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Vikram Chandrashekhar</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=vikramc1" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://vivekg.dev/"><img src="https://avatars.githubusercontent.com/u/29757116?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Vivek Gopalakrishnan</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=v715" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/zeou1"><img src="https://avatars.githubusercontent.com/u/38440136?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ze Ou</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=zeou1" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/alyakin314"><img src="https://avatars.githubusercontent.com/u/25692376?v=4?s=100" width="100px;" alt=""/><br /><sub><b>alyakin314</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=alyakin314" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/dfrancisco1998"><img src="https://avatars.githubusercontent.com/u/40680427?v=4?s=100" width="100px;" alt=""/><br /><sub><b>dfrancisco1998</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=dfrancisco1998" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/dlee0156"><img src="https://avatars.githubusercontent.com/u/47963020?v=4?s=100" width="100px;" alt=""/><br /><sub><b>dlee0156</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=dlee0156" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/emasquil"><img src="https://avatars.githubusercontent.com/u/29291336?v=4?s=100" width="100px;" alt=""/><br /><sub><b>emasquil</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=emasquil" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/gkang7"><img src="https://avatars.githubusercontent.com/u/55039574?v=4?s=100" width="100px;" alt=""/><br /><sub><b>gkang7</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=gkang7" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/hhelm10"><img src="https://avatars.githubusercontent.com/u/31412718?v=4?s=100" width="100px;" alt=""/><br /><sub><b>hhelm10</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=hhelm10" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/jheiko1"><img src="https://avatars.githubusercontent.com/u/39324337?v=4?s=100" width="100px;" alt=""/><br /><sub><b>jheiko1</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=jheiko1" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/Jingyan230"><img src="https://avatars.githubusercontent.com/u/69659070?v=4?s=100" width="100px;" alt=""/><br /><sub><b>jingyan230</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=Jingyan230" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/kareef928"><img src="https://avatars.githubusercontent.com/u/51966539?v=4?s=100" width="100px;" alt=""/><br /><sub><b>kareef928</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=kareef928" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/Kikiwink"><img src="https://avatars.githubusercontent.com/u/50060770?v=4?s=100" width="100px;" alt=""/><br /><sub><b>kikiwink</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=Kikiwink" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/PerifanosPrometheus"><img src="https://avatars.githubusercontent.com/u/69210497?v=4?s=100" width="100px;" alt=""/><br /><sub><b>perifanosprometheus</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=PerifanosPrometheus" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/spencer-loggia"><img src="https://avatars.githubusercontent.com/u/36051767?v=4?s=100" width="100px;" alt=""/><br /><sub><b>spencer-loggia</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=spencer-loggia" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/tliu68"><img src="https://avatars.githubusercontent.com/u/54865879?v=4?s=100" width="100px;" alt=""/><br /><sub><b>tliu68</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=tliu68" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/vmdhhh"><img src="https://avatars.githubusercontent.com/u/58106524?v=4?s=100" width="100px;" alt=""/><br /><sub><b>vmdhhh</b></sub></a><br /><a href="https://github.com/microsoft/graspologic/commits?author=vmdhhh" title="Code">💻</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

